==> starling-framework-2.5.1.tgz: package/README.md <==
[![Simplified BSD License](https://img.shields.io/badge/license-BSD-blue.svg?style=flat)](LICENSE.md) [![NPM Version](https://img.shields.io/npm/v/starling-framework.svg?style=flat)](http://npmjs.com/package/starling-framework) [![Haxelib Version](https://img.shields.io/github/tag/openfl/starling.svg?style=flat&label=haxelib)](http://lib.haxe.org/p/starling) [![Build Status](https://img.shields.io/circleci/project/github/openfl/starling/master.svg)](https://circleci.com/gh/openfl/starling)

Starling Framework
==================

The Cross Platform Game Engine
------------------------------

The Starling Framework allows you to create hardware accelerated apps in ActionScript 3, Haxe, TypeScript or JavaScript. The main target is the creation of 2D games, but Starling may be used for any graphical application. Thanks to Adobe AIR, Starling-based applications can be deployed to mobile devices (iOS, Android), the desktop (Windows, OS X), and to the browser (via the Flash plugin).

You can also pair Starling with OpenFL to deploy native builds for iOS, Android, Windows, OS X, Linux or WebAssembly, as well as Flash/AIR or regular HTML5 releases without WebAssembly. HTML5 support is available in TypeScript, Haxe, ES5 JavaScript or ES6+ JavaScript.

While Starling mimics the classic display tree architecture of Adobe AIR/Flash, it provides much better performance than the Adobe version: all objects are rendered directly by the GPU (using the Stage3D API). When paired with OpenFL, Starling provides an alternative GPU renderer with helpful features. The complete architecture was designed for working well with the GPU; common game development tasks were built right into its core. Starling hides Stage3D internals from developers, but makes it easy to access them for those who need full performance and flexibility.

Starling aims to be as lightweight and easy to use as possible. As an open-source project, much care was taken to make the source code easy to read, understand and extend. With under 15k lines of code, experienced developers can easily grasp it in its entirety, or modify it to their needs.

Getting Started (NPM)
---------------------

You can install the Yeoman generator to create an empty project:

```bash
npm install -g yo starling-framework-generator
mkdir StarlingProject
cd StarlingProject
yo starling-framework
```

You can also try the Starling demo:

```bash
git clone https://github.com/openfl/starling
cd starling/samples/demo_npm/typescript
npm install
npm start -s
```

There are ES5, ES6, Haxe and TypeScript versions of the demo available.

Getting Started (Haxelib)
-------------------------

You can easily install Starling using haxelib:

    haxelib install starling

To add it to an OpenFL project, add this to your project file:

```xml
<haxelib name="starling" />
```

You can also create a new empty project like this:

```bash
openfl create starling:project StarlingProject
```

You can also try the Starling demo:

```bash
openfl create starling:demo
cd demo
openfl test flash
```

Quick Links (AS3)
-----------------

* [Official Homepage](http://www.starling-framework.org)
* [Instruction Manual](http://manual.starling-framework.org)
* [API Reference](http://doc.starling-framework.org)
* [Support Forum](http://forum.starling-framework.org)
* [Starling Wiki](http://wiki.starling-framework.org)
  * [Showcase](http://wiki.starling-framework.org/games/start)
  * [Extensions](http://wiki.starling-framework.org/extensions/start)
* [OpenFL Support Forum](http://community.openfl.org)

News and Updates
----------------

* [Twitter](https://twitter.com/gamua)
* [Facebook](https://facebook.com/gamua.co)
* [Google+](https://www.google.com/+gamua)
* [LinkedIn](https://www.linkedin.com/company/gamua)

==> starling-framework-2.7.0.tgz: package/README.md <==
[![Simplified BSD License](https://img.shields.io/badge/license-BSD-blue.svg?style=flat)](LICENSE.md) [![NPM Version](https://img.shields.io/npm/v/starling-framework.svg?style=flat)](http://npmjs.com/package/starling-framework) [![Haxelib Version](https://img.shields.io/github/tag/openfl/starling.svg?style=flat&label=haxelib)](http://lib.haxe.org/p/starling) [![Build Status](https://img.shields.io/circleci/project/github/openfl/starling/master.svg)](https://circleci.com/gh/openfl/starling)

Starling Framework
==================

The Cross Platform Game Engine
------------------------------

The Starling Framework allows you to create hardware accelerated apps in ActionScript 3, Haxe, TypeScript or JavaScript. The main target is the creation of 2D games, but Starling may be used for any graphical application. Thanks to Adobe AIR, Starling-based applications can be deployed to mobile devices (iOS, Android), the desktop (Windows, OS X), and to the browser (via the Flash plugin).

You can also pair Starling with OpenFL to deploy native builds for iOS, Android, Windows, OS X, Linux or WebAssembly, as well as Flash/AIR or regular HTML5 releases without WebAssembly. HTML5 support is available in TypeScript, Haxe, ES5 JavaScript or ES6+ JavaScript.

While Starling mimics the classic display tree architecture of Adobe AIR/Flash, it provides much better performance than the Adobe version: all objects are rendered directly by the GPU (using the Stage3D API). When paired with OpenFL, Starling provides an alternative GPU renderer with helpful features. The complete architecture was designed for working well with the GPU; common game development tasks were built right into its core. Starling hides Stage3D internals from developers, but makes it easy to access them for those who need full performance and flexibility.

Starling aims to be as lightweight and easy to use as possible. As an open-source project, much care was taken to make the source code easy to read, understand and extend. With under 15k lines of code, experienced developers can easily grasp it in its entirety, or modify it to their needs.

Getting Started (NPM)
---------------------

You can install the Yeoman generator to create an empty project:

```bash
npm install -g yo starling-framework-generator
mkdir StarlingProject
cd StarlingProject
yo starling-framework
```

You can also try the Starling demo:

```bash
git clone https://github.com/openfl/starling
cd starling/samples/demo_npm/typescript
npm install
npm start -s
```

There are AS3, ES5, ES6, Haxe and TypeScript versions of the demo available.

Getting Started (Haxelib)
-------------------------

You can easily install Starling using haxelib:

    haxelib install starling

To add it to an OpenFL project, add this to your project file:

```xml
<haxelib name="starling" />
```

You can also create a new empty project like this:

```bash
openfl create starling:project StarlingProject
```

You can also try the Starling demo:

```bash
openfl create starling:demo
cd demo
openfl test flash
```

Note about high-dpi support
---------------------------
Starling supports high-dpi devices such as 4K monitors
For it to work you need to add this in your project file:
```xml
<window allow-high-dpi="true"/>
```
You also need to tell starling to support high resolutions in your code:
```bash
starling.supportHighResolutions = true;
```

Quick Links (AS3)
-----------------

* [Official Homepage](http://www.starling-framework.org)
* [Instruction Manual](http://manual.starling-framework.org)
* [API Reference](http://doc.starling-framework.org)
* [Support Forum](http://forum.starling-framework.org)
* [Starling Wiki](http://wiki.starling-framework.org)
  * [Showcase](http://wiki.starling-framework.org/games/start)
  * [Extensions](http://wiki.starling-framework.org/extensions/start)
* [OpenFL Support Forum](http://community.openfl.org)

News and Updates
----------------

* [Twitter](https://twitter.com/gamua)
* [Facebook](https://facebook.com/gamua.co)
* [Google+](https://www.google.com/+gamua)
* [LinkedIn](https://www.linkedin.com/company/gamua)
